@@ -1,6 +1,6 @@
 from .asgi import ASGIRouteHandler, asgi
 from .base import BaseRouteHandler
-from .http import HTTPRouteHandler, delete, get, patch, post, put, route
+from .http import HTTPRouteHandler, delete, get, head, patch, post, put, route
 from .websocket import WebsocketRouteHandler, websocket
 
 __all__ = (
@@ -10,6 +10,7 @@ __all__ = (
     "WebsocketRouteHandler",
     "asgi",
     "delete",
+    "head",
     "get",
     "patch",
     "post",
