@@ -1,7 +1,7 @@
 from .base import PluginMapping, PluginProtocol, get_plugin_for_value
 
-__all__ = [
+__all__ = (
     "PluginMapping",
     "PluginProtocol",
     "get_plugin_for_value",
-]
+)
