@@ -37,7 +37,7 @@ class TortoiseORMPlugin(PluginProtocol[Model]):
         for (
             field_name,
             tortoise_model_field,
-        ) in model_class._meta.fields_map.items():  # pylint: disable=protected-access
+        ) in model_class._meta.fields_map.items():
             if field_name in pydantic_model.__fields__:
                 if (
                     is_pydantic_model(pydantic_model.__fields__[field_name].type_)
@@ -67,7 +67,7 @@ class TortoiseORMPlugin(PluginProtocol[Model]):
             if model_class not in self._data_models_map:
                 fields_to_exclude: List[str] = [
                     field_name
-                    for field_name, tortoise_model_field in model_class._meta.fields_map.items()  # pylint: disable=protected-access
+                    for field_name, tortoise_model_field in model_class._meta.fields_map.items()
                     if isinstance(tortoise_model_field, (RelationalField, ReverseRelation)) or tortoise_model_field.pk
                 ]
                 kwargs.update(
