@@ -41,12 +41,10 @@ param_type_map = {
 
 
 parsers_map: Dict[Any, Callable[[Any], Any]] = {
-    str: str,
     float: float,
     int: int,
     Decimal: Decimal,
     UUID: UUID,
-    Path: lambda x: Path(re.sub("//+", "", (x.lstrip("/")))),
     date: parse_date,
     datetime: parse_datetime,
     time: parse_time,
@@ -88,9 +86,9 @@ class BaseRoute(ABC):
             methods: Supported methods
         """
         self.path, self.path_format, self.path_components = self._parse_path(path)
-        self.path_parameters: List[PathParameterDefinition] = [
+        self.path_parameters: Tuple[PathParameterDefinition, ...] = tuple(
             component for component in self.path_components if isinstance(component, PathParameterDefinition)
-        ]
+        )
         self.handler_names = handler_names
         self.scope_type = scope_type
         self.methods = set(methods or [])
@@ -169,7 +167,7 @@ class BaseRoute(ABC):
                 cls._validate_path_parameter(param)
                 param_name, param_type = (p.strip() for p in param.split(":"))
                 type_class = param_type_map[param_type]
-                parser = parsers_map[type_class]
+                parser = parsers_map[type_class] if type_class not in {str, Path} else None
                 parsed_components.append(
                     PathParameterDefinition(name=param_name, type=type_class, full=param, parser=parser)
                 )
